import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { CopyFileRequest } from "../models/CopyFileRequest";
import type { DeleteFileBatchRequestV2 } from "../models/DeleteFileBatchRequestV2";
import type { FileDetails } from "../models/FileDetails";
import type { FilePath } from "../models/FilePath";
export declare class FileV2Service {
    /**
     * Gets the full details (e.g. metadata, tags, etc.) for a file.
     * @param accountId
     * @param filePath
     * @returns FileDetails Success.
     * @throws ApiError
     */
    static getFileDetails(accountId: AccountId, filePath: FilePath): Promise<FileDetails>;
    /**
     * Copies a file synchronously.
     * @param accountId
     * @param requestBody
     * @returns void
     * @throws ApiError
     */
    static copyFile(accountId: AccountId, requestBody: CopyFileRequest): Promise<void>;
    /**
     * Deletes a file synchronously.
     * @param accountId
     * @param filePath
     * @returns void
     * @throws ApiError
     */
    static deleteFile(accountId: AccountId, filePath: FilePath): Promise<void>;
    /**
     * Deletes multiple files asynchronously.
     * @param accountId
     * @param requestBody
     * @returns AsyncResponse Success.
     * @throws ApiError
     */
    static deleteFileBatch(accountId: AccountId, requestBody: DeleteFileBatchRequestV2): Promise<AsyncResponse>;
}
