/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { AsyncResponse } from "../models/AsyncResponse";
import type { CopyFolderRequest } from "../models/CopyFolderRequest";
import type { DeleteFolderBatchRequest } from "../models/DeleteFolderBatchRequest";
import type { DeleteFolderRequest } from "../models/DeleteFolderRequest";
import type { FolderDetails } from "../models/FolderDetails";
import type { FolderPath } from "../models/FolderPath";
import type { IncludeExternal } from "../models/IncludeExternal";
import type { IncludeFiles } from "../models/IncludeFiles";
import type { IncludePhysicalFolders } from "../models/IncludePhysicalFolders";
import type { IncludeVirtualFolders } from "../models/IncludeVirtualFolders";
import type { IterateFolderRecursively } from "../models/IterateFolderRecursively";
import type { ListFolderChildrenResponse } from "../models/ListFolderChildrenResponse";
import type { ListFolderCursor } from "../models/ListFolderCursor";
import type { ListFolderDryRun } from "../models/ListFolderDryRun";
import type { ListFolderItemLimit } from "../models/ListFolderItemLimit";
import type { ListFolderResponse } from "../models/ListFolderResponse";
import type { PutFolderRequest } from "../models/PutFolderRequest";
import { request as __request } from "../core/request";

export class FolderService {
  /**
   * Creates or updates the folder specified by the `folderPath`.
   *
   * If the folder's ancestors do not exist, they will be created automatically (with empty FolderSettings).
   *
   * Note: you don't need to create folders before uploading files to them.
   * @param accountId
   * @param requestBody
   * @returns FolderDetails Success.
   * @throws ApiError
   */
  public static async putFolder(accountId: AccountId, requestBody: PutFolderRequest): Promise<FolderDetails> {
    const result = await __request({
      method: "PUT",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Gets the full details (e.g. permission, storage layer, etc.) for a folder.
   *
   * Returns an empty object if no settings have been configured for this folder.
   * @param accountId
   * @param folderPath
   * @returns FolderDetails Success.
   * @throws ApiError
   */
  public static async getFolderDetails(accountId: AccountId, folderPath: FolderPath): Promise<FolderDetails> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/folders`,
      query: {
        folderPath: folderPath
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Deletes a folder asynchronously.
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolder(accountId: AccountId, requestBody: DeleteFolderRequest): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Lists the children (files and sub-folders) of a folder.
   *
   * Pagination is complete when the response `cursor` matches the request `cursor`.
   * @param accountId
   * @param folderPath
   * @param cursor
   * @param includeFiles
   * @param includeFolders
   * @param internal
   * @param limit
   * @returns ListFolderChildrenResponse Success.
   * @throws ApiError
   */
  public static async listFolderChildren(
    accountId: AccountId,
    folderPath: FolderPath,
    cursor?: ListFolderCursor,
    includeFiles?: IncludeFiles,
    includeFolders?: boolean,
    internal?: boolean,
    limit?: ListFolderItemLimit
  ): Promise<ListFolderChildrenResponse> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/folders/children`,
      query: {
        folderPath: folderPath,
        cursor: cursor,
        includeFiles: includeFiles,
        includeFolders: includeFolders,
        internal: internal,
        limit: limit
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Lists the folder's contents.
   *
   * Pagination is complete when the response `cursor` is `null` or matches the request `cursor`.
   * @param accountId
   * @param folderPath
   * @param cursor
   * @param dryRun
   * @param includeExternalItems
   * @param includeFiles
   * @param includePhysicalFolders
   * @param includeVirtualFolders
   * @param limit
   * @param recursive
   * @returns ListFolderResponse Success.
   * @throws ApiError
   */
  public static async listFolder(
    accountId: AccountId,
    folderPath: FolderPath,
    cursor?: ListFolderCursor,
    dryRun?: ListFolderDryRun,
    includeExternalItems?: IncludeExternal,
    includeFiles?: IncludeFiles,
    includePhysicalFolders?: IncludePhysicalFolders,
    includeVirtualFolders?: IncludeVirtualFolders,
    limit?: ListFolderItemLimit,
    recursive?: IterateFolderRecursively
  ): Promise<ListFolderResponse> {
    const result = await __request({
      method: "GET",
      path: `/v2/accounts/${accountId}/folders/list`,
      query: {
        folderPath: folderPath,
        cursor: cursor,
        dryRun: dryRun,
        includeExternalItems: includeExternalItems,
        includeFiles: includeFiles,
        includePhysicalFolders: includePhysicalFolders,
        includeVirtualFolders: includeVirtualFolders,
        limit: limit,
        recursive: recursive
      },
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Copies a folder asynchronously.
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async copyFolder(accountId: AccountId, requestBody: CopyFolderRequest): Promise<AsyncResponse> {
    const result = await __request({
      method: "POST",
      path: `/v2/accounts/${accountId}/folders/copy`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple folders asynchronously.
   * @param accountId
   * @param requestBody
   * @returns AsyncResponse Success.
   * @throws ApiError
   */
  public static async deleteFolderBatch(
    accountId: AccountId,
    requestBody: DeleteFolderBatchRequest
  ): Promise<AsyncResponse> {
    const result = await __request({
      method: "DELETE",
      path: `/v2/accounts/${accountId}/folders/batch`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }
}
